@@ -2,36 +2,47 @@
 //!
 //! # Examples
 //!
-//! ```rust
-//! use structopt::StructOpt;
+//! ```rust,no_run
+//! use clap::Parser;
 //! use clap_verbosity_flag::Verbosity;
 //!
 //! /// Le CLI
-//! #[derive(Debug, StructOpt)]
+//! #[derive(Debug, Parser)]
 //! struct Cli {
-//!     #[structopt(flatten)]
+//!     #[clap(flatten)]
 //!     verbose: Verbosity,
 //! }
-//! #
-//! # fn main() {}
+//!
+//! let cli = Cli::parse();
+//! env_logger::Builder::new()
+//!     .filter_level(cli.verbose.log_level_filter())
+//!     .init();
 //! ```
+//!
+//! This will only report errors.
+//! - `-q` silences output
+//! - `-v` show warnings
+//! - `-vv` show info
+//! - `-vvv` show debug
+//! - `-vvvv` show trace
 
 use log::Level;
+use log::LevelFilter;
 
-#[derive(structopt::StructOpt, Debug, Clone)]
+#[derive(clap::Args, Debug, Clone)]
 pub struct Verbosity {
     /// Pass many times for more log output
     ///
     /// By default, it'll only report errors. Passing `-v` one time also prints
     /// warnings, `-vv` enables info logging, `-vvv` debug, and `-vvvv` trace.
-    #[structopt(long, short = "v", parse(from_occurrences))]
+    #[clap(long, short = 'v', parse(from_occurrences))]
     verbose: i8,
 
     /// Pass many times for less log output
-    #[structopt(long, short = "q", parse(from_occurrences), conflicts_with = "verbose")]
+    #[clap(long, short = 'q', parse(from_occurrences), conflicts_with = "verbose")]
     quiet: i8,
 
-    #[structopt(skip)]
+    #[clap(skip)]
     default: i8,
 }
 
@@ -44,8 +55,12 @@ impl Verbosity {
             default,
         }
     }
+
     /// Change the default level.
     ///
+    /// When the level is lower than `log::Error` (the default), multiple `-q`s will be needed for
+    /// complete silence
+    ///
     /// `None` means all output is disabled.
     pub fn set_default(&mut self, level: Option<Level>) {
         self.default = level_value(level);
@@ -58,6 +73,13 @@ impl Verbosity {
         level_enum(self.verbosity())
     }
 
+    /// Get the log level filter.
+    pub fn log_level_filter(&self) -> LevelFilter {
+        level_enum(self.verbosity())
+            .map(|l| l.to_level_filter())
+            .unwrap_or(log::LevelFilter::Off)
+    }
+
     /// If the user requested complete silence (i.e. not just no-logging).
     pub fn is_silent(&self) -> bool {
         self.log_level().is_none()
@@ -94,6 +116,23 @@ use std::fmt;
 
 impl fmt::Display for Verbosity {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.verbose)
+        write!(f, "{}", self.verbosity())
+    }
+}
+
+#[cfg(test)]
+mod test {
+    use super::*;
+
+    #[test]
+    fn verify_app() {
+        #[derive(Debug, clap::StructOpt)]
+        struct Cli {
+            #[clap(flatten)]
+            verbose: Verbosity,
+        }
+
+        use clap::IntoApp;
+        Cli::into_app().debug_assert()
     }
 }
